@@ -35,8 +35,6 @@ static void *__init check_function_address(void *ptr, char *symbol)
 		printk(KERN_ERR "Guessed %s is %s\n", symbol, buf);
 		return NULL;
 	}
-#else
-	printk(KERN_INFO "%s=%p\n", symbol, ptr);
 #endif
 	return ptr;
 }
@@ -582,7 +580,6 @@ struct security_operations * __init probe_security_ops(void)
 		printk(KERN_ERR "Can't resolve security_ops structure.\n");
 		return NULL;
 	}
-	printk(KERN_INFO "security_ops=%p\n", ptr);
 	ops = *ptr;
 	if (!ops) {
 		printk(KERN_ERR "No security_operations registered.\n");
@@ -715,7 +712,6 @@ void * __init probe_vfsmount_lock(void)
 		printk(KERN_ERR "Can't resolve vfsmount_lock .\n");
 		return NULL;
 	}
-	printk(KERN_INFO "vfsmount_lock=%p\n", ptr);
 	return ptr;
 }
 
@@ -776,7 +772,6 @@ void * __init probe_vfsmount_lock(void)
 		printk(KERN_ERR "Can't resolve vfsmount_lock .\n");
 		return NULL;
 	}
-	printk(KERN_INFO "vfsmount_lock=%p\n", ptr);
 	return ptr;
 }
 
@@ -822,7 +817,6 @@ void * __init probe_vfsmount_lock(void)
 		printk(KERN_ERR "Can't resolve vfsmount_lock .\n");
 		return NULL;
 	}
-	printk(KERN_INFO "vfsmount_lock=%p\n", ptr);
 	return ptr;
 }
 
